menu
ml_transformer package
documentation
dart_transformers.dart
ByteTokenizer class
ByteTokenizer class
dark_mode
light_mode
ByteTokenizer
class
Constructors
ByteTokenizer
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
vocabSize
→
int
final
Methods
decode
(
List
<
int
>
ids
)
→
String
encode
(
String
text
)
→
List
<
int
>
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
ml_transformer package
documentation
dart_transformers
ByteTokenizer class
dart_transformers library