GPTConfig class

Constructors

GPTConfig({required int vocabSize, required int maxSeqLen, required int dModel, required int nHeads, required int nLayers, int ffnMult = 4, bool tieWeights = true, bool rope = true})
const

Properties

dModel int
final
ffnMult int
final
hashCode int
The hash code for this object.
no setterinherited
maxSeqLen int
final
nHeads int
final
nLayers int
final
rope bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tieWeights bool
final
vocabSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited