KVCache class

Constructors

KVCache(int nHeads, int headDim)

Properties

hashCode int
The hash code for this object.
no setterinherited
headDim int
final
kHeads List<Tensor2D>
final
length int
no setter
nHeads int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vHeads List<Tensor2D>
final

Methods

append(List<Tensor2D> kNew, List<Tensor2D> vNew) → void
Append new key/value rows for each head (each arg shape (T, headDim)).
getK(int h) Tensor2D
getV(int h) Tensor2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited