LayerNorm class

Constructors

LayerNorm(int dim, {Float64List? gamma, Float64List? beta, double eps = 1e-5})

Properties

beta Float64List
final
dim int
final
eps double
final
gamma Float64List
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forward(Tensor2D x) Tensor2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited