Linear class

Constructors

Linear(int inFeatures, int outFeatures, {Tensor2D? weight, Float64List? bias, int seed = 123})

Properties

b Float64List
final
hashCode int
The hash code for this object.
no setterinherited
inFeatures int
final
outFeatures int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
w Tensor2D
final

Methods

forward(Tensor2D x) Tensor2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited