MultiHeadAttention class

Constructors

MultiHeadAttention(int dModel, int nHeads, {RoPE? rope})

Properties

dModel int
final
hashCode int
The hash code for this object.
no setterinherited
headDim int
final
nHeads int
final
rope RoPE?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wk Linear
final
wo Linear
final
wq Linear
final
wv Linear
final

Methods

forward(Tensor2D x, {KVCache? cache}) Tensor2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited