RoPE class

Constructors

RoPE(RoPEConfig cfg)
const

Properties

cfg RoPEConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyInPlace(Tensor2D t) → void
Apply RoPE to t of shape (T, headDim). headDim must be even.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited