Sampler class

Constructors

Sampler(SamplerConfig cfg, {int seed = 1337})

Properties

cfg SamplerConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sampleNext(Float64List logits, List<int> recent) int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited