SamplerConfig class

Constructors

SamplerConfig({double temperature = 1.0, int topK = 0, double topP = 1.0, double repetitionPenalty = 1.0, int penaltyWindow = 64})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
penaltyWindow int
final
repetitionPenalty double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double
final
topK int
final
topP double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited